import { EventEmitter, OnInit } from '@angular/core';
import { ValueAccessor } from '../interfaces/value-accessor';
import { NgControl } from '@angular/forms';
import * as i0 from "@angular/core";
/**
 * Directive handling `ReactiveForms` binding.
 *
 * @usageNotes
 *
 * ### Example binding a text input
 *
 * ```html
 * <input
 *   type="text"
 *   id="demo-text-input"
 *   controlValueAccessor
 *   initFromStorage
 *   prefix="demo"
 *   [formControl]="textControl"
 * />
 * ```
 */
export declare class ControlValueAccessorDirective implements OnInit, ValueAccessor {
    /**
     * Emitter for value changes.
     */
    readonly valueChange: EventEmitter<unknown>;
    /**
     * The control to bind to.
     */
    readonly ngControl: NgControl | null;
    private readonly destroyRef;
    /**
     * Sets up event observer for value changes.
     */
    ngOnInit(): void;
    /**
     * Writes the value to the control.
     * @param value Value to write
     * @param falsyTransformer *optional* transformer handling falsy values
     */
    writeValue(value: unknown, falsyTransformer?: (() => unknown) | undefined): void;
    /**
     * Gets the current control value.
     */
    getValue(): unknown;
    static ɵfac: i0.ɵɵFactoryDeclaration<ControlValueAccessorDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ControlValueAccessorDirective, never, never, {}, {}, never, never, true, never>;
}
