import { AfterViewInit, EventEmitter } from '@angular/core';
import { ValueAccessor } from '../interfaces/value-accessor';
import * as i0 from "@angular/core";
/**
 * Directive handling native control binding.
 *
 * @usageNotes
 *
 * ### Example binding a text input
 *
 * ```html
 * <input
 *   type="text"
 *   id="demo-text-input"
 *   ngxLocalStorage="native-text-input"
 *   initFromStorage
 *   prefix="demo"
 *   forEvent="input"
 *   valuePath="value"
 * />
 * ```
 *
 */
export declare class NativeValueAccessorDirective implements AfterViewInit, ValueAccessor {
    /**
     * The event to hook onto for observing value changes.
     */
    forEvent?: string;
    /**
     * Provides a path to access the bound elements value property.
     */
    valuePath: string[];
    /**
     * An optional debounce for storage write access after value changes.
     */
    storageDebounce: number;
    /**
     * Emitter for value changes.
     */
    readonly valueChange: EventEmitter<unknown>;
    private readonly elementRef;
    private readonly destroyRef;
    /**
     * Sets up event observer for value changes.
     */
    ngAfterViewInit(): void;
    /**
     * Writes the value to the control.
     * @param value Value to write
     * @param falsyTransformer *optional* transformer handling falsy values
     */
    writeValue(value: unknown, falsyTransformer?: () => unknown): void;
    /**
     * Gets the current control value.
     */
    getValue(): unknown;
    private getValuePath;
    static ɵfac: i0.ɵɵFactoryDeclaration<NativeValueAccessorDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NativeValueAccessorDirective, never, never, { "forEvent": { "alias": "forEvent"; "required": false; }; "valuePath": { "alias": "valuePath"; "required": false; }; "storageDebounce": { "alias": "storageDebounce"; "required": false; }; }, {}, never, never, true, never>;
    static ngAcceptInputType_valuePath: unknown;
    static ngAcceptInputType_storageDebounce: unknown;
}
