import { OnDestroy } from '@angular/core';
import { NgxLocalstorageConfiguration } from '../interfaces/storage-configuration';
import { Observable } from 'rxjs';
import { ServiceOptions } from '../interfaces/service-options';
import * as i0 from "@angular/core";
/**
 * Provides a service to access the localstorage.
 */
export declare class LocalStorageService extends Observable<StorageEvent> implements OnDestroy {
    /**
     * Configuration used by the service.
     */
    readonly config: NgxLocalstorageConfiguration;
    private readonly onError;
    private readonly subscriptions;
    private readonly serializer;
    private readonly storageSupport;
    private readonly storage;
    private readonly window;
    /**
     * Creates a new instance.
     */
    constructor(_config?: NgxLocalstorageConfiguration);
    ngOnDestroy(): void;
    /**
     * Gets the number of entries in the applications storage.
     */
    count(): number | undefined;
    /**
     * Returns the nth (defined by the index parameter) key in the storage.
     * The order of keys is user-agent defined, so you should not rely on it.
     * @param index An integer representing the number of the key you want to get the name of. This is a zero-based index.
     */
    getKey(index: number): string | null | undefined;
    /**
     * Adds the value with the given key or updates an existing entry.
     * @param key Key identifying the wanted entry.
     * @param value Value to store.
     * @param options Options for overwriting configuration with the following properties:
     * * `prefix`: (Optional) Prefix to overwrite the configured one.
     * * `serializer`: (Optional) Serializer to overwrite the configured one.
     */
    set<T = unknown>(key: string, value: T, options?: ServiceOptions): void;
    /**
     * Gets the entry specified by the given key if existing - otherwise `null`.
     * @param key Key identifying the wanted entry.
     * @param options Options for overwriting configuration with the following properties:
     * * `prefix`: (Optional) Prefix to overwrite the configured one.
     * * `serializer`: (Optional) Serializer to overwrite the configured one.
     */
    get<T = unknown>(key: string, options?: ServiceOptions): T | null;
    /**
     * Removes the entry specified by the given key.
     * @param key Key identifying the entry to remove.
     * @param prefix Optional prefix to overwrite the configured one.
     */
    remove(key: string, prefix?: string): void;
    /**
     * Clears all entries of the storage.
     */
    clear(): void;
    /**
     * Triggers the service to emit the given error.
     * @param error Error to emit through the service.
     */
    error(error: string | Error | unknown): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<LocalStorageService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<LocalStorageService>;
}
